@@ -1,7 +1,5 @@
 context("Mortality")
 
-library(raster)
-
 
 # Create the samc object
 samc_obj <- samc(res, abs, fid, tr_fun = function(x) 1/mean(x), override = TRUE)
@@ -18,7 +16,7 @@ diag(R) <- samc_obj@p[-nrow(samc_obj@p), ncol(samc_obj@p)]
 I <- diag(nrow(Q))
 
 # Prepare the occupancy data
-occ_ras <- raster(occ)
+occ_ras <- raster::raster(occ)
 pv <- as.vector(occ_ras)
 pv <- pv[is.finite(pv)]
 
@@ -63,6 +61,27 @@ test_that("Testing mortality(samc, origin, time)", {
   expect_equal(as.vector(r1), as.vector(r2[row, ]))
 })
 
+test_that("Testing mortality(samc, origin, time_vec)", {
+
+  r1 <- mortality(samc_obj, origin = row, time = time_vec)
+
+  for (i in 1:length(time_vec)) {
+    r2 <- diag(nrow(Q))
+
+    Qt <- diag(nrow(Q))
+
+    for (j in 1:(time_vec[i] - 1)) {
+      Qt <- Qt %*% Q
+      r2 <- r2 + Qt
+    }
+
+    r2 <- r2 %*% R
+
+    # Verify
+    expect_equal(r1[[i]], as.vector(r2[row, ]))
+  }
+})
+
 test_that("Testing mortality(samc, dest, time)", {
 
   r1 <- mortality(samc_obj, dest = col, time = time)
@@ -82,7 +101,28 @@ test_that("Testing mortality(samc, dest, time)", {
   expect_equal(as.vector(r1), as.vector(r2[, col]))
 })
 
-test_that("Testing mortality(samc, dest, time)", {
+test_that("Testing mortality(samc, dest, time_vec)", {
+
+  r1 <- mortality(samc_obj, dest = col, time = time_vec)
+
+  for (i in 1:length(time_vec)) {
+    r2 <- diag(nrow(Q))
+
+    Qt <- diag(nrow(Q))
+
+    for (j in 1:(time_vec[i] - 1)) {
+      Qt <- Qt %*% Q
+      r2 <- r2 + Qt
+    }
+
+    r2 <- r2 %*% R
+
+    # Verify
+    expect_equal(r1[[i]], as.vector(r2[, col]))
+  }
+})
+
+test_that("Testing mortality(samc, origin, dest, time)", {
 
   r1 <- mortality(samc_obj, origin = row, dest = col, time = time)
 
@@ -101,6 +141,27 @@ test_that("Testing mortality(samc, dest, time)", {
   expect_equal(as.vector(r1), as.vector(r2[row, col]))
 })
 
+test_that("Testing mortality(samc, origin, dest, time_vec)", {
+
+  r1 <- mortality(samc_obj, origin = row, dest = col, time = time_vec)
+
+  for (i in 1:length(time_vec)) {
+    r2 <- diag(nrow(Q))
+
+    Qt <- diag(nrow(Q))
+
+    for (j in 1:(time_vec[i] - 1)) {
+      Qt <- Qt %*% Q
+      r2 <- r2 + Qt
+    }
+
+    r2 <- r2 %*% R
+
+    # Verify
+    expect_equal(r1[[i]], as.vector(r2[row, col]))
+  }
+})
+
 test_that("Testing mortality(samc, occ, time)", {
 
   r1 <- mortality(samc_obj, occ = occ, time = time)
@@ -120,6 +181,27 @@ test_that("Testing mortality(samc, occ, time)", {
   expect_equal(as.vector(r1), as.vector(r2))
 })
 
+test_that("Testing mortality(samc, occ, time_vec)", {
+
+  r1 <- mortality(samc_obj, occ = occ, time = time_vec)
+
+  for (i in 1:length(time_vec)) {
+    r2 <- I
+
+    Qt <- diag(nrow(Q))
+
+    for (j in 1:(time_vec[i] - 1)) {
+      Qt <- Qt %*% Q
+      r2 <- r2 + Qt
+    }
+
+    r2 <- pv %*% r2 %*% R
+
+    # Verify
+    expect_equal(r1[[i]], as.vector(r2))
+  }
+})
+
 test_that("Testing mortality(samc)", {
 
   r1 <- mortality(samc_obj)
